@@ -77,7 +77,7 @@ def main():
         col1,col2,col3,col4,col5=st.columns(5)
         with col1:
             title=st.text_input('Title:','Monthly<br>Sales')
-            valueText=st.text_input('Text Value:','Argentina')
+            valueText=st.text_input('Text Value:','Bryan is winning 10k')
             unit=st.text_input('Value Unit:','Mb')
             backgroundColor=st.text_input('Background Color (str/hex):','#f3f3f3')  
         with col2:    
